@@ -36,12 +36,19 @@ namespace Convert
     QString toString(const KgpgCore::KgpgKeyOwnerTrust ownertrust);
     QString toString(const KgpgCore::KgpgKeyTrust trust);
     QString toString(const QDate &date);
+    QString toString(const KgpgCore::KgpgSubKeyType type);
     KgpgKeyAlgo toAlgo(const uint v);
     KgpgKeyAlgo toAlgo(const QString &s);
     KgpgKeyTrust toTrust(const QChar &c);
     KgpgKeyTrust toTrust(const QString &s);
     KgpgKeyOwnerTrust toOwnerTrust(const QChar &c);
     KgpgKeyOwnerTrust toOwnerTrust(const QString &s);
+    /**
+     * @brief parse the GnuPG capabilities field
+     * @param capString the capability string as returned by GnuPG
+     * @param upper if the uppercase or lowercase version should be parsed
+     */
+    KgpgSubKeyType toSubType(const QString &capString, bool upper);
 }
 
 } // namespace KgpgCore
