@@ -49,12 +49,8 @@ public:
 
     int newInstance ();
     bool running;
-    KUrl::List urlList;
     KShortcut goHome;
 
-protected:
-    KCmdLineArgs *args;
-
 private:
     KGpgExternalActions *w;
     KeysManager *s_keyManager;
